@@ -24,6 +24,7 @@ class Service:
         self.start_timeout = 90
 
         self.container = None
+        self.options = None
 
         self.populateConfig()
 
@@ -231,8 +232,10 @@ class Service:
 
         # Rewrite https config
         if self.config.https:
-            for key in self.options["https"].keys():
-                self.attrs[key] = self.options["https"][key]
+            if self.options:
+                if "https" in self.options:
+                    for key in self.options["https"].keys():
+                        self.attrs[key] = self.options["https"][key]
 
     def _status(self):
         docker_client = docker.from_env()
